@@ -117,6 +117,8 @@ def is_int(value: Any) -> bool:
     """Return True if value is a int"""
     if isinstance(value, int):
         return True
+    if isinstance(value, float):
+        return value.is_integer()
     _value: str = str(value)
     if _value[0] in ("-", "+"):
         return str(_value[1:]).isdigit()
@@ -134,6 +136,8 @@ class JsonObj(MutableMapping[str, _VT], Generic[_VT]):
     JsonObj(foo='bar')['foo'] == JsonObj(foo='bar').foo
 
     Examples:
+        >>> print(JsonObj())
+        JsonObj(**{})
         >>> d = {"uno": 1, "dos": 2, "tres": 3}
         >>> d
         {'uno': 1, 'dos': 2, 'tres': 3}
@@ -225,7 +229,7 @@ class JsonObj(MutableMapping[str, _VT], Generic[_VT]):
         try:
             assert all(isinstance(k, str) for k in self._data)
         except AssertionError:
-            d = {k: v for k, v in self._data.items() if not isinstance(k, str)}
+            d = {k: v for k, v in self._data.items() if not isinstance(k, str)}  # type: ignore[redundant-expr]
             raise ValueError(
                 "JsonObj keys MUST be strings! Bad key values: {}".format(str(d))
             )
@@ -243,7 +247,7 @@ class JsonObj(MutableMapping[str, _VT], Generic[_VT]):
         """Function place holder that is called after object initialization"""
         pass  # pylint: disable=unnecessary-pass
 
-    def __contains__(self, key: _KT) -> bool:  # type: ignore
+    def __contains__(self, key: _KT) -> bool:  # type: ignore[override]
         """Check if a key or dot-key is contained within the JsonObj object
 
         Args:
@@ -404,7 +408,7 @@ class JsonObj(MutableMapping[str, _VT], Generic[_VT]):
     def setdefault(self, key: _KT, default: Optional[_VT] = None) -> _VT:
         if default:
             return self._data.setdefault(key, default)
-        return self._data.setdefault(key)
+        return self._data.setdefault(key)  # type: ignore[call-arg]
 
     def clear(self) -> None:
         self._data.clear()
@@ -504,11 +508,11 @@ class JsonObj(MutableMapping[str, _VT], Generic[_VT]):
                         if not isinstance(v, (dict, JsonObj))
                         else JsonObj(v).filter_none(recursive=True)
                         for k, v in self.items()
-                        if v is not None
+                        if v is not None  # type: ignore[redundant-expr]
                     },
                 )
             )
-        return JsonObj({k: v for k, v in self.items() if v is not None})
+        return JsonObj({k: v for k, v in self.items() if v is not None})  # type: ignore[redundant-expr]
 
     def filter_false(self, recursive: bool = False) -> JsonObj[_VT]:
         """Filter key-values where the value is false-y
@@ -718,10 +722,18 @@ class JsonObj(MutableMapping[str, _VT], Generic[_VT]):
         """Return list of tuples of the form (dot-key, value)"""
         return list(self.dot_items())
 
+    def __bool__(self) -> bool:
+        return bool(self._data)
+
+    def _is_empty(self) -> bool:
+        return not bool(self._data)
+
     def to_str(self, minify: bool = False, width: Optional[int] = None) -> str:
         """Return a string representation of the JsonObj object"""
         if minify:
             return type(self).__name__ + "(**" + str(self.to_dict()) + ")"
+        if not bool(self._data):
+            return f"{type(self).__name__}(**{{}})"
         _width = get_terminal_size(fallback=(88, 24)).columns - 12
         return "".join(
             [
@@ -748,7 +760,7 @@ class JsonObj(MutableMapping[str, _VT], Generic[_VT]):
     def _cls_attr_names(cls) -> Set[str]:
         """Return attrs-attribute names for an object decorated with attrs"""
         try:
-            return {el.name for el in cls.__attrs_attrs__}  # type: ignore
+            return {el.name for el in cls.__attrs_attrs__}  # type: ignore[attr-defined]
         except AttributeError:
             raise AttributeError("Class is not decorated with attr.attrs")
 
@@ -756,7 +768,7 @@ class JsonObj(MutableMapping[str, _VT], Generic[_VT]):
     def _cls_fields(cls) -> Set[str]:
         """Return attrs-attribute names for an object decorated with attrs"""
         try:
-            return cls.__fields__  # type: ignore
+            return cls.__fields__  # type: ignore[attr-defined, no-any-return]
         except AttributeError:
             raise AttributeError("Class does not inherit from pydantic.BaseModel")
 
@@ -764,7 +776,7 @@ class JsonObj(MutableMapping[str, _VT], Generic[_VT]):
     def _cls_field_names(cls) -> Set[str]:
         """Return attrs-attribute names for an object decorated with attrs"""
         try:
-            return set(cls.__fields__)  # type: ignore
+            return set(cls.__fields__)  # type: ignore[attr-defined]
         except AttributeError:
             raise AttributeError("Class does not inherit from pydantic.BaseModel")
 
@@ -1081,7 +1093,7 @@ class JSONMeta(type):
     """Meta type for use by JSON class to allow for static `__call__` method"""
 
     @staticmethod
-    def __call__(value: Optional[Any] = None) -> Any:  # type: ignore
+    def __call__(value: Optional[Any] = None) -> Any:  # type: ignore[override]
         if value is None:
             value = {}
         return jsonify(value)
@@ -1212,18 +1224,30 @@ class JSON(metaclass=JSONMeta):
         )
 
     @staticmethod
-    def loads(string: Union[bytes, str], obj: bool = False, **kwargs: Any) -> Any:
+    def loads(
+        string: Union[bytes, str], obj: bool = False, jsonc: bool = False, **kwargs: Any
+    ) -> Any:
         """Parse JSON string/bytes and return raw representation"""
         if obj:
-            return jsonify(jsonlib.loads(string, **kwargs))
-        return jsonlib.loads(string, **kwargs)
+            return jsonify(jsonlib.loads(string, jsonc=jsonc, **kwargs))
+        return jsonlib.loads(string, jsonc=jsonc, **kwargs)
 
     @staticmethod
-    def parse(string: Union[bytes, str], obj: bool = True) -> Any:
-        """Parse JSON string/bytes and jsonify all dictionaries -> JsonObj"""
+    def parse(
+        string: Union[bytes, str], obj: bool = False, jsonc: bool = False, **kwargs: Any
+    ) -> Any:
+        """Parse JSON string/bytes"""
         if obj:
-            return jsonify(jsonlib.loads(string))
-        return jsonlib.loads(string)
+            return jsonify(jsonlib.loads(string, jsonc=jsonc, **kwargs))
+        return jsonlib.loads(string, jsonc=jsonc, **kwargs)
+
+    @staticmethod
+    def orjson_useable() -> bool:
+        return jsonlib.orjson_useable()
+
+    @staticmethod
+    def rapidjson_useable() -> bool:
+        return jsonlib.rapidjson_useable()
 
     @staticmethod
     def use_orjson() -> None:
@@ -1260,7 +1284,7 @@ class JSON(metaclass=JSONMeta):
 
 class JSONModuleCls(ModuleType, JSON):
     @staticmethod
-    def __call__(value: Any = None):  # type: ignore
+    def __call__(value: Any = None):  # type: ignore[no-untyped-def]
         """Jsonify a value"""
         if value is None:
             return JsonObj()
