@@ -1,4 +1,6 @@
 # -*- coding: utf-8 -*-
+from __future__ import annotations
+
 import os
 
 from typing import Any
@@ -13,7 +15,7 @@ except ModuleNotFoundError:
             "starlette not found/installed; `pip install starlette`"
         )
     else:
-        Response = object  # type: ignore
+        Response = object  # type: ignore[assignment, misc]
 
 __all__ = ("JSONBOURNEResponse",)
 
