@@ -1,6 +1,8 @@
 # -*- coding: utf-8 -*-
 """jsonbourne jsonlib api"""
 # pyright: reportOptionalMemberAccess=false
+from __future__ import annotations
+
 import json as pyjson
 
 from abc import ABC, abstractmethod
@@ -9,13 +11,14 @@ from decimal import Decimal
 from pathlib import Path
 from sys import modules as _sys_modules
 from typing import Any, Callable, List, Optional, Tuple, Type, Union
+from uuid import UUID
 
 from jsonbourne.protocols import Dumpable, JsonInterfaceProtocol
 
 try:
     import dataclasses
 except ImportError:
-    dataclasses = None  # type: ignore
+    dataclasses = None  # type: ignore[assignment]
 
 try:
     import rapidjson
@@ -34,7 +37,7 @@ try:
     import orjson
 
 except ImportError:
-    orjson = None  # type: ignore
+    orjson = None  # type: ignore[assignment]
 
 try:
     import numpy as np
@@ -70,7 +73,7 @@ def _json_encode_default(obj: Any) -> Any:
             return int(obj)
         if isinstance(obj, (np.ndarray, np.generic)):
             return obj.tolist()
-    if dataclasses:
+    if dataclasses is not None:
         if dataclasses.is_dataclass(obj):
             return dataclasses.asdict(obj)
     if isinstance(obj, bytes):
@@ -79,6 +82,8 @@ def _json_encode_default(obj: Any) -> Any:
         return tuple(obj)
     if isinstance(obj, Path):
         return str(obj)
+    if isinstance(obj, UUID):
+        return str(obj)
     if isinstance(obj, (datetime, dttime, dtdate)):
         return obj.isoformat()
     if isinstance(obj, timedelta):
@@ -126,7 +131,7 @@ class JsonLibABC(ABC):
 
     @staticmethod
     @abstractmethod
-    def loads(string: Union[bytes, str], **kwargs: Any) -> Any:
+    def loads(string: Union[bytes, str], jsonc: bool = False, **kwargs: Any) -> Any:
         ...
 
     @staticmethod
@@ -212,7 +217,11 @@ class JSON_STDLIB(JsonLibABC):
         ).encode()
 
     @staticmethod
-    def loads(string: Union[bytes, str], **kwargs: Any) -> Any:
+    def loads(string: Union[bytes, str], jsonc: bool = False, **kwargs: Any) -> Any:
+        if jsonc:
+            raise NotImplementedError(
+                "Python stdlib-json does not support JSONC; use rapidjson"
+            )
         return pyjson.loads(string, **kwargs)
 
     @staticmethod
@@ -290,7 +299,9 @@ class ORJSON(JsonLibABC):
         )
 
     @staticmethod
-    def loads(string: Union[bytes, str], **kwargs: Any) -> Any:
+    def loads(string: Union[bytes, str], jsonc: bool = False, **kwargs: Any) -> Any:
+        if jsonc:
+            raise NotImplementedError("orjson does not support JSONC; use rapidjson")
         return orjson.loads(string)
 
     @staticmethod
@@ -345,6 +356,8 @@ class RAPIDJSON(JsonLibABC):
                 sort_keys=sort_keys,
                 default=default or _json_encode_default,
                 datetime_mode=rapidjson.DM_ISO8601,
+                number_mode=rapidjson.NM_NAN,
+                uuid_mode=rapidjson.UM_CANONICAL,
                 **kwargs,
             )
         )
@@ -373,7 +386,9 @@ class RAPIDJSON(JsonLibABC):
         ).encode()
 
     @staticmethod
-    def loads(string: Union[bytes, str], **kwargs: Any) -> Any:
+    def loads(string: Union[bytes, str], jsonc: bool = False, **kwargs: Any) -> Any:
+        if jsonc and "parse_mode" not in kwargs:
+            kwargs["parse_mode"] = rapidjson.PM_COMMENTS
         return rapidjson.loads(string, **kwargs)
 
     @staticmethod
@@ -449,12 +464,18 @@ def import_json(
 
 class JsonLib:
     _jsonlib: Type[JsonLibABC]
+    _oj: Optional[Type[ORJSON]] = None
+    _rj: Optional[Type[RAPIDJSON]] = None
 
     def __init__(self, jsonlib: Optional[Type[JsonLibABC]] = None):
         if jsonlib:
             self._jsonlib = jsonlib
         else:
             self._jsonlib = import_json()
+        if ORJSON.useable():
+            self._oj = ORJSON
+        if RAPIDJSON.useable():
+            self._rj = RAPIDJSON
 
     def dumps(
         self,
@@ -496,8 +517,19 @@ class JsonLib:
             **kwargs,
         )
 
-    def loads(self, string: Union[bytes, str], **kwargs: Any) -> Any:
-        return self._jsonlib.loads(string, **kwargs)
+    def loads(
+        self, string: Union[bytes, str], jsonc: bool = False, **kwargs: Any
+    ) -> Any:
+        if jsonc:
+            if self._rj:
+                return self._rj.loads(string, jsonc=jsonc, **kwargs)
+        return self._jsonlib.loads(string, jsonc=jsonc, **kwargs)
+
+    def orjson_useable(self) -> bool:
+        return ORJSON.useable()
+
+    def rapidjson_useable(self) -> bool:
+        return RAPIDJSON.useable()
 
     def use_orjson(self) -> None:
         self._jsonlib = _import_orjson()
@@ -535,7 +567,8 @@ class JsonLib:
         )
 
 
-JSONLIB: Type[JsonLibABC] = import_json()
+_JSONLIB: Type[JsonLibABC] = import_json()
+JSONLIB = JsonLib(_JSONLIB)
 
 
 def dumps(
@@ -578,8 +611,12 @@ def dumpb(
     )
 
 
-def loads(string: Union[bytes, str], **kwargs: Any) -> Any:
-    return JSONLIB.loads(string, **kwargs)
+def loads(string: Union[bytes, str], jsonc: bool = False, **kwargs: Any) -> Any:
+    return JSONLIB.loads(string, jsonc=jsonc, **kwargs)
+
+
+def parse(string: Union[bytes, str], jsonc: bool = False, **kwargs: Any) -> Any:
+    return JSONLIB.loads(string, jsonc=jsonc, **kwargs)
 
 
 def jsoncp(
@@ -602,19 +639,24 @@ def jsoncp(
     )
 
 
+def orjson_useable() -> bool:
+    return JSONLIB.orjson_useable()
+
+
+def rapidjson_useable() -> bool:
+    return JSONLIB.rapidjson_useable()
+
+
 def use_orjson() -> None:
-    global JSONLIB
-    JSONLIB = _import_orjson()
+    JSONLIB.use_orjson()
 
 
 def use_rapidjson() -> None:
-    global JSONLIB
-    JSONLIB = _import_rapidjson()
+    JSONLIB.use_rapidjson()
 
 
 def use_json_stdlib() -> None:
-    global JSONLIB
-    JSONLIB = _import_json_stdlib()
+    JSONLIB.use_json_stdlib()
 
 
 def use_json() -> None:
@@ -622,4 +664,4 @@ def use_json() -> None:
 
 
 def which() -> str:
-    return JSONLIB.lib
+    return JSONLIB.which()
